'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.calculateTiles = calculateTiles;

var _invariant = require('invariant');

var _invariant2 = _interopRequireDefault(_invariant);

var _percent = require('percent');

var _percent2 = _interopRequireDefault(_percent);

var _cssLayout = require('css-layout');

var _cssLayout2 = _interopRequireDefault(_cssLayout);

var _lodash = require('lodash.merge');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function calculateTiles() {
  var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  (0, _invariant2.default)(typeof options.width === 'number', 'Must provide numeric width to calculateTiles');
  (0, _invariant2.default)(typeof options.height === 'number', 'Must provide numeric height to calculateTiles');
  (0, _invariant2.default)(options.rows !== undefined, 'Must provide rows to calculateTiles');
  (0, _invariant2.default)(options.columns !== undefined, 'Must provide columns to calculateTiles');

  var width = options.width;
  var height = options.height;
  var rowsCount = options.rows;
  var columnsCount = options.columns;


  var rowStyle = function rowStyle() {
    return { flex: 1 };
  };
  var columnStyle = function columnStyle() {
    return { flex: 1 };
  };

  var treeNode = {
    style: {
      width: width,
      height: height,
      flexWrap: 'nowrap',
      flexDirection: 'column'
    },
    children: []
  };

  for (var y = 0; y < rowsCount; y++) {
    var columnNodes = [];

    for (var x = 0; x < columnsCount; x++) {
      columnNodes.push({
        style: columnStyle((0, _lodash2.default)({}, options, { row: y, column: y }))
      });
    }

    treeNode.children.push({
      style: (0, _lodash2.default)({
        flexDirection: 'row',
        flexWrap: 'nowrap'
      }, rowStyle((0, _lodash2.default)({}, options, { row: y }))),
      children: columnNodes
    });
  }

  (0, _cssLayout2.default)(treeNode);

  var result = [];

  for (var _y = 0; _y < rowsCount; _y++) {
    var row = treeNode.children[_y];

    for (var _x2 = 0; _x2 < columnsCount; _x2++) {
      var column = row.children[_x2];

      result.push({
        row: _y,
        column: _x2,
        left: Math.round(column.layout.left),
        top: Math.round(row.layout.top),
        right: Math.round(column.layout.left + column.layout.width),
        bottom: Math.round(row.layout.top + row.layout.height)
      });
    }
  }

  var margin = options.margin || 0;

  result.forEach(function (tile) {
    var tileWidth = tile.right - tile.left;
    var tileHeight = tile.bottom - tile.top;

    var marginVertical = void 0;
    var marginHorizontal = void 0;

    if (_percent2.default.valid(margin)) {
      marginVertical = _percent2.default.convert(margin) / 100 * tileHeight;
      marginHorizontal = _percent2.default.convert(margin) / 100 * tileWidth;
    } else {
      marginVertical = marginHorizontal = margin;
    }

    if (columnsCount > 1) {
      var marginLeft = Math.round(tile.column * marginHorizontal / (columnsCount - 1));
      var marginRight = marginHorizontal - marginLeft;
      tile.left = Math.max(0, tile.left - marginLeft);
      tile.right = Math.min(width, tile.right + marginRight);
    }

    if (rowsCount > 1) {
      var marginTop = Math.round(tile.row * marginVertical / (rowsCount - 1));
      var marginBottom = marginVertical - marginTop;
      tile.top = Math.max(0, tile.top - marginTop);
      tile.bottom = Math.min(height, tile.bottom + marginBottom);
    }
  });

  result.forEach(function (tile) {
    tile.width = tile.right - tile.left;
    tile.height = tile.bottom - tile.top;
    delete tile.right;
    delete tile.bottom;
  });

  return result;
}