'use strict';

var _ava = require('ava');

var _ava2 = _interopRequireDefault(_ava);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function calculateTiles(params) {
  var tiles = (0, _utils.calculateTiles)(params);

  tiles.forEach(function (tile) {
    delete tile.row;
    delete tile.column;
  });

  return tiles;
}

(0, _ava2.default)('can extract just single tile', function (t) {
  var result = calculateTiles({
    width: 20,
    height: 20,
    columns: 1,
    rows: 1
  });

  t.deepEqual(result, [{ left: 0, top: 0, width: 20, height: 20 }]);
});

(0, _ava2.default)('can perform simple division without overlap', function (t) {
  var result = calculateTiles({
    width: 40,
    height: 20,
    columns: 2,
    rows: 2
  });

  t.deepEqual(result, [{ left: 0, top: 0, width: 20, height: 10 }, { left: 20, top: 0, width: 20, height: 10 }, { left: 0, top: 10, width: 20, height: 10 }, { left: 20, top: 10, width: 20, height: 10 }]);
});

(0, _ava2.default)('properly rounds on uneven divide', function (t) {
  var result = calculateTiles({
    width: 8,
    height: 8,
    columns: 3,
    rows: 3
  });

  t.deepEqual(result, [{ left: 0, top: 0, width: 3, height: 3 }, { left: 3, top: 0, width: 2, height: 3 }, { left: 5, top: 0, width: 3, height: 3 }, { left: 0, top: 3, width: 3, height: 2 }, { left: 3, top: 3, width: 2, height: 2 }, { left: 5, top: 3, width: 3, height: 2 }, { left: 0, top: 5, width: 3, height: 3 }, { left: 3, top: 5, width: 2, height: 3 }, { left: 5, top: 5, width: 3, height: 3 }]);
});

(0, _ava2.default)('can perform simple division with margin in percents', function (t) {
  var result = calculateTiles({
    width: 40,
    height: 20,
    columns: 2,
    rows: 2,
    margin: '50%'
  });

  t.deepEqual(result, [{ left: 0, top: 0, width: 30, height: 15 }, { left: 10, top: 0, width: 30, height: 15 }, { left: 0, top: 5, width: 30, height: 15 }, { left: 10, top: 5, width: 30, height: 15 }]);
});

(0, _ava2.default)('properly rounds on uneven divide with overlap', function (t) {
  var result = calculateTiles({
    width: 60,
    height: 90,
    columns: 3,
    rows: 3,
    margin: '50%'
  });

  t.deepEqual(result, [{ left: 0, top: 0, width: 30, height: 45 }, { left: 15, top: 0, width: 30, height: 45 }, { left: 30, top: 0, width: 30, height: 45 }, { left: 0, top: 22, width: 30, height: 45 }, { left: 15, top: 22, width: 30, height: 45 }, { left: 30, top: 22, width: 30, height: 45 }, { left: 0, top: 45, width: 30, height: 45 }, { left: 15, top: 45, width: 30, height: 45 }, { left: 30, top: 45, width: 30, height: 45 }]);
});